using Jypeli;
using Jypeli.Assets;
using Jypeli.Controls;
using Jypeli.Widgets;
using System;
using System.Collections.Generic;

namespace Sammakkopeli
{
    public class Sammakkopeli : PhysicsGame
    {
        Vector suunta;

        PhysicsObject sammakko;

        Timer hyppyLaskuri;
        Timer tarkastaLiike;

        int sammakkoTippuuKertoja;
        bool onkoHypannut = false;

        double nopeusX = 0.0;
        double nopeusY = -800.0;

        public override void Begin()
        {
            AlustaKentta();
            AsetaOhjaimet();
            Keyboard.Listen(Key.Escape, ButtonState.Pressed, ConfirmExit, "Lopeta peli");
        }


        public void AsetaOhjaimet()
        {
            Keyboard.Listen(Key.Left, ButtonState.Down, AsetaNopeus, null, -1);
            Keyboard.Listen(Key.Left, ButtonState.Released, PysaytaSammakko, null);

            Keyboard.Listen(Key.Right, ButtonState.Down, AsetaNopeus, null, 1);
            Keyboard.Listen(Key.Right, ButtonState.Released, PysaytaSammakko, null);

            Keyboard.Listen(Key.Space, ButtonState.Pressed, SammakkoHyppaa, null, 10);
        }


        void AsetaNopeus(int suunta)
        {
            nopeusX = suunta * 600.0;
            SammakkoHyppaa(6);
        }


        void PysaytaSammakko()
        {
            nopeusX = 0.0;
        }


        public void AlustaKentta()
        {
            Level.BackgroundColor = Color.Aqua;

            ColorTileMap ruudut = ColorTileMap.FromLevelAsset("Kentta1");
            ruudut.SetTileMethod(Color.Gold, LuoTaso);
            ruudut.SetTileMethod(Color.Red, LuoPelihahmo);
            ruudut.SetTileMethod(Color.Orange, LuoHilleri);
            ruudut.SetTileMethod(Color.Black, LuoKarpanen);

            ruudut.Execute(20, 20);

            Camera.Follow(sammakko);

            hyppyLaskuri = new Timer();
            hyppyLaskuri.Interval = 0.05;
            hyppyLaskuri.Timeout += SammakkoTippuu;

            tarkastaLiike = new Timer();
            tarkastaLiike.Interval = 0.05;
            tarkastaLiike.Timeout += LiikutaPelihahmoa;
            tarkastaLiike.Start();
        }


        public void LuoPelihahmo(Vector paikka, double leveys, double korkeus)
        {
            sammakko = new PhysicsObject(40.0, 26.0);
            sammakko.Image = LoadImage("Sammakko.png");
            sammakko.Position = paikka;
            sammakko.CanRotate = false;
            Add(sammakko);

            AddCollisionHandler(sammakko, KasitteleSammakonTormays);
        }



        public void LiikutaPelihahmoa()
        {
            suunta = new Vector(nopeusX, nopeusY);
            sammakko.Velocity = suunta;
        }


        public void SammakkoHyppaa(int korkeus)
        {
            if (onkoHypannut == false)
            {
                onkoHypannut = true;
                sammakkoTippuuKertoja = korkeus;
                hyppyLaskuri.Start(20);
            }
        }


        void SammakkoTippuu()
        {
            sammakkoTippuuKertoja -= 1;
            if (sammakkoTippuuKertoja < -9)
            {
                nopeusY = -1000.0;
                return;
            }
            nopeusY = sammakkoTippuuKertoja * 100;
        }


        void KasitteleSammakonTormays(PhysicsObject tormaaja, PhysicsObject kohde)
        {
            onkoHypannut = false;
        }

        public void LuoTaso(Vector paikka, double leveys, double korkeus)
        {
            PhysicsObject taso = PhysicsObject.CreateStaticObject(leveys, korkeus);
            taso.Position = paikka;
            taso.Shape = Shape.Rectangle;
            taso.Color = Color.Orange;
            taso.CollisionIgnoreGroup = 1;
            Add(taso);
        }

        public void LuoHilleri(Vector paikka, double leveys, double korkeus)
        {
            PhysicsObject hilleri = new PhysicsObject(100, 70);
            hilleri.IgnoresCollisionResponse = true;
            hilleri.Position = paikka;
            hilleri.Image = LoadImage("Hilleri.png");
            Add(hilleri);
        }

        public void LuoKarpanen(Vector paikka, double leveys, double korkeus)
        {
            PhysicsObject karpanen = PhysicsObject.CreateStaticObject(leveys, korkeus);
            karpanen.Position = paikka;
            karpanen.Image = LoadImage("Karpane.png");
            karpanen.IgnoresCollisionResponse = true;
            karpanen.Tag = "karpanen";
            Add(karpanen);
        }
    }
}